# Changelog

- Rectangles now honor the theme's shadow color

## 0.7

- New example: multi-page website
- New component: CodeBlock
- UserSettings can now have mutable default values
- Removed "undefined space"
